@@ -1,7 +1,7 @@
 """This is the "nester.py" module and it provides one function called print_lol()
    which prints lists that may or may not include nested list. """
 
-def print_lol(the_list, need_intent = false, level = 0):
+def print_lol(the_list, need_intent = False, level = 0):
   """This function takes one positional argument called "the_list", which 
    	      in any Python list (of - possibly - nested lists). Each data item in the 
    	      provided list is (recursively) printed to the screen on it's own line."""
@@ -11,8 +11,7 @@ def print_lol(the_list, need_intent = false, level = 0):
       print_lol(each_item, need_intent, level+1)
     else:
       if need_intent:
-        for x in range(0,level):
-      	  print("\t", end='')
+      	print("\t" * level, end='')
       print(each_item)
 
 movies = ["The Holy Grail", 1975 , "Terry Jones & Terry Gilliam", 91, ["Graham Chapman", ["Michael Palin", "John Cleese", "Terry Gilliam", "Eric Idle", "Terry Jones"]]]
